@@ -60,7 +60,7 @@ inline QString makeStateGroup(int id, const QString &name)
 class KolfContactListener : public b2ContactListener
 {
 	public:
-		void PreSolve(b2Contact* contact, const b2Manifold* oldManifold) Q_DECL_OVERRIDE
+		void PreSolve(b2Contact* contact, const b2Manifold* oldManifold) override
 		{
 			Q_UNUSED(oldManifold)
 			CanvasItem* citemA = static_cast<CanvasItem*>(contact->GetFixtureA()->GetBody()->GetUserData());
@@ -280,8 +280,9 @@ HoleConfig::HoleConfig(HoleInfo *holeInfo, QWidget *parent)
 	par->setSingleStep( 1 );
 	par->setValue(holeInfo->par());
 	hlayout->addWidget(par);
-	connect(par, QOverload<int>::of(&QSpinBox::valueChanged), this, &HoleConfig::parChanged);
-	hlayout->addStretch();
+        connect(par, qOverload<int>(&QSpinBox::valueChanged), this,
+                &HoleConfig::parChanged);
+        hlayout->addStretch();
 
 	hlayout->addWidget(new QLabel(i18n("Maximum:"), this));
 	QSpinBox *maxstrokes = new QSpinBox(this);
@@ -292,9 +293,10 @@ HoleConfig::HoleConfig(HoleInfo *holeInfo, QWidget *parent)
 	maxstrokes->setSpecialValueText(i18n("Unlimited"));
 	maxstrokes->setValue(holeInfo->maxStrokes());
 	hlayout->addWidget(maxstrokes);
-	connect(maxstrokes, QOverload<int>::of(&QSpinBox::valueChanged), this, &HoleConfig::maxStrokesChanged);
+        connect(maxstrokes, qOverload<int>(&QSpinBox::valueChanged), this,
+                &HoleConfig::maxStrokesChanged);
 
-	QCheckBox *check = new QCheckBox(i18n("Show border walls"), this);
+        QCheckBox *check = new QCheckBox(i18n("Show border walls"), this);
 	check->setChecked(holeInfo->borderWalls());
 	layout->addWidget(check);
 	connect(check, &QCheckBox::toggled, this, &HoleConfig::borderWallsChanged);
@@ -920,12 +922,12 @@ void KolfGame::setShowInfo(bool yes)
 {
 	m_showInfo = yes;
 	QList<QGraphicsItem*> infoItems;
-	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
+	for (QGraphicsItem* qitem : std::as_const(m_topLevelQItems)) {
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
 			infoItems << citem->infoItems();
 	}
-	for (QGraphicsItem* qitem : qAsConst(infoItems))
+	for (QGraphicsItem* qitem : std::as_const(infoItems))
 		qitem->setVisible(m_showInfo);
 }
 
@@ -1314,7 +1316,7 @@ void KolfGame::autoSaveTimeout()
 void KolfGame::recreateStateList()
 {
 	savedState.clear();
-	for (QGraphicsItem* item : qAsConst(m_topLevelQItems)) {
+	for (QGraphicsItem* item : std::as_const(m_topLevelQItems)) {
 		if (dynamic_cast<Ball*>(item)) continue; //see below
 		CanvasItem* citem = dynamic_cast<CanvasItem*>(item);
 		if (citem)
@@ -1339,7 +1341,7 @@ void KolfGame::undoShot()
 
 void KolfGame::loadStateList()
 {
-	for (QGraphicsItem* item : qAsConst(m_topLevelQItems)) {
+	for (QGraphicsItem* item : std::as_const(m_topLevelQItems)) {
 		if (dynamic_cast<Ball*>(item)) continue; //see below
 		CanvasItem* citem = dynamic_cast<CanvasItem*>(item);
 		if (citem)
@@ -1543,7 +1545,7 @@ void KolfGame::startBall(const Vector &velocity)
 	(*curPlayer).ball()->setVelocity(velocity);
 	(*curPlayer).ball()->shotStarted();
 
-	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
+	for (QGraphicsItem* qitem : std::as_const(m_topLevelQItems)) {
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
 			citem->shotStarted();
@@ -1751,7 +1753,7 @@ void KolfGame::showInfoDlg(bool addDontShowAgain)
 			i18n("Course name: %1", holeInfo.name()) + QStringLiteral("\n")
 			+ i18n("Created by %1", holeInfo.author()) + QStringLiteral("\n")
 			+ i18np("%1 hole", "%1 holes", highestHole),
-			i18n("Course Information"),
+			i18nc("@title:window", "Course Information"),
 			addDontShowAgain? holeInfo.name() + QStringLiteral(" ") + holeInfo.author() : QString());
 }
 
@@ -1942,7 +1944,7 @@ void KolfGame::addNewObject(const QString& identifier)
 	for (;; ++i)
 	{
 		bool found = false;
-		for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
+		for (QGraphicsItem* qitem : std::as_const(m_topLevelQItems)) {
 			CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 			if (citem)
 			{
@@ -2164,7 +2166,7 @@ void KolfGame::save()
 				return;
 			}
 			else {
-				setFilename(newfile.url());
+				setFilename(newfile.toLocalFile());
 			}
 		}
 		delete fileSaveDialog;
@@ -2182,7 +2184,7 @@ void KolfGame::save()
 		if (holeNum == curHole)
 			cfg->deleteGroup(*it);
 	}
-	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
+	for (QGraphicsItem* qitem : std::as_const(m_topLevelQItems)) {
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
 		{
@@ -2242,7 +2244,7 @@ void KolfGame::toggleEditMode()
 	}
 
 	// alert our items
-	for (QGraphicsItem* qitem : qAsConst(m_topLevelQItems)) {
+	for (QGraphicsItem* qitem : std::as_const(m_topLevelQItems)) {
 		if (dynamic_cast<Ball*>(qitem)) continue;
 		CanvasItem *citem = dynamic_cast<CanvasItem *>(qitem);
 		if (citem)
@@ -2278,7 +2280,7 @@ void KolfGame::setSelectedItem(CanvasItem* citem)
 	selectedItem = qitem;
 	Q_EMIT newSelectedItem(qitem ? citem : &holeInfo);
 	//deactivate all other overlays
-	for (QGraphicsItem* otherQitem : qAsConst(m_topLevelQItems)) {
+	for (QGraphicsItem* otherQitem : std::as_const(m_topLevelQItems)) {
 		CanvasItem* otherCitem = dynamic_cast<CanvasItem*>(otherQitem);
 		if (otherCitem && otherCitem != citem)
 		{
@@ -2307,7 +2309,7 @@ bool KolfGame::allPlayersDone()
 
 void KolfGame::setBorderWalls(bool showing)
 {
-	for (Kolf::Wall* wall : qAsConst(borderWalls))
+	for (Kolf::Wall* wall : std::as_const(borderWalls))
 		wall->setVisible(showing);
 }
 
